Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3270)

Unified Diff: cc/animation/animation.h

Issue 1912023003: CC Animation: Remove Observers and Observations in namings. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@observertype
Patch Set: Rename it in .cc comments as well Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | cc/animation/animation.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/animation/animation.h
diff --git a/cc/animation/animation.h b/cc/animation/animation.h
index fff74fad900f7a46f24b757e87d4896c895c7775..ba0b5171d0667c7715741f1db29ea762e3f31c4c 100644
--- a/cc/animation/animation.h
+++ b/cc/animation/animation.h
@@ -159,15 +159,15 @@ class CC_EXPORT Animation {
void set_is_impl_only(bool is_impl_only) { is_impl_only_ = is_impl_only; }
bool is_impl_only() const { return is_impl_only_; }
- void set_affects_active_observers(bool affects_active_observers) {
- affects_active_observers_ = affects_active_observers;
+ void set_affects_active_elements(bool affects_active_elements) {
+ affects_active_elements_ = affects_active_elements;
}
- bool affects_active_observers() const { return affects_active_observers_; }
+ bool affects_active_elements() const { return affects_active_elements_; }
- void set_affects_pending_observers(bool affects_pending_observers) {
- affects_pending_observers_ = affects_pending_observers;
+ void set_affects_pending_elements(bool affects_pending_elements) {
+ affects_pending_elements_ = affects_pending_elements;
}
- bool affects_pending_observers() const { return affects_pending_observers_; }
+ bool affects_pending_elements() const { return affects_pending_elements_; }
private:
Animation(std::unique_ptr<AnimationCurve> curve,
@@ -230,18 +230,18 @@ class CC_EXPORT Animation {
bool is_impl_only_;
// When pushed from a main-thread controller to a compositor-thread
// controller, an animation will initially only affect pending observers
// (corresponding to layers in the pending tree). Animations that only
// affect pending observers are able to reach the STARTING state and tick
// pending observers, but cannot proceed any further and do not tick active
// observers. After activation, such animations affect both kinds of observers
// and are able to proceed past the STARTING state. When the removal of
// an animation is pushed from a main-thread controller to a
// compositor-thread controller, this initially only makes the animation
- // stop affecting pending observers. After activation, such animations no
- // longer affect any observers, and are deleted.
- bool affects_active_observers_;
- bool affects_pending_observers_;
+ // stop affecting pending elements. After activation, such animations no
+ // longer affect any elements, and are deleted.
+ bool affects_active_elements_;
+ bool affects_pending_elements_;
DISALLOW_COPY_AND_ASSIGN(Animation);
};
« no previous file with comments | « no previous file | cc/animation/animation.cc » ('j') | no next file with comments »
@@ -230,18 +230,18 @@ class CC_EXPORT Animation {
bool is_impl_only_;
// When pushed from a main-thread controller to a compositor-thread
- // controller, an animation will initially only affect pending observers
+ // controller, an animation will initially only affect pending elements
// (corresponding to layers in the pending tree). Animations that only
@@ -230,18 +230,18 @@ class CC_EXPORT Animation {
// (corresponding to layers in the pending tree). Animations that only
- // affect pending observers are able to reach the STARTING state and tick
- // pending observers, but cannot proceed any further and do not tick active
- // observers. After activation, such animations affect both kinds of observers
+ // affect pending elements are able to reach the STARTING state and tick
+ // pending elements, but cannot proceed any further and do not tick active
+ // elements. After activation, such animations affect both kinds of elements
// and are able to proceed past the STARTING state. When the removal of
// an animation is pushed from a main-thread controller to a

Powered by Google App Engine
This is Rietveld 408576698